#
# spec file for package python-wsproto
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-wsproto
Version:        1.2.0
Release:        4.6
Summary:        WebSockets state-machine based protocol implementation
License:        MIT
Group:          Development/Languages/Python
URL:            https://pypi.python.org/pypi/wsproto
Source:         https://files.pythonhosted.org/packages/source/w/wsproto/wsproto-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.7}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-h11 >= 0.9.0
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module h11 >= 0.9.0}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
This module contains a pure-Python implementation of a WebSocket
protocol stack. It's written from the ground up to be embeddable in
whatever program you choose to use, ensuring that you can
communicate via WebSockets, as defined in RFC6455
<https://tools.ietf.org/html/rfc6455>, regardless of your
programming paradigm.

This module does not provide a parsing layer, a network layer, or
any rules about concurrency. Instead, it's a purely in-memory
solution, defined in terms of data actions and WebSocket frames.
RFC6455 and Compression Extensions for WebSocket via RFC7692
<https://tools.ietf.org/html/rfc7692> are fully supported.

%prep
%autosetup -p1 -n wsproto-%{version}

%build
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE
%{python_sitelib}/wsproto
%{python_sitelib}/wsproto-%{version}*-info

%changelog
* Mon Jan 29 2024 Dirk Müller <dmueller@suse.com>
- spec file cleanup
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Wed Feb  1 2023 Dirk Müller <dmueller@suse.com>
- no longer supports python 3.6, we can drop the 3.6 specific requires
* Mon Oct  3 2022 Dirk Müller <dmueller@suse.com>
- update to 1.2.0:
  * Bugfix: When a close frame with status NO_STATUS_RCVD is sent, send
    and empty payload.
  * Bugfix: Changing both encoding and decoding of the Host, from ascii
    to idna.
  * Bugfix: Support multiple Sec-WebSocket-Extensions and
    Sec-WebSocket-Protocol headers.
  * Accept bytes alongside string as path argument in
    initiate_upgrade_connection.
  * Check the state when sending events, raising if the event cannot be
    sent in the current state.
  * Send an empty payload for NO_STATUS_RCVD.
  * Added support for Python 3.10.
  * Drop support for Python 3.6, meaning the minimum supported version
    is Python 3.7.0.
  * Various type checking and code linting improvements.
- drop 170.patch (upstream)
* Mon Feb 21 2022 Dirk Müller <dmueller@suse.com>
- add 170.patch to improve python 3.10 compatibility
- reenable tests
* Thu Feb 17 2022 Dirk Müller <dmueller@suse.com>
- filter two irrelevant tests for h11 0.13.0 (gh#python-hyper/wsproto#169)
- fix version dependency on h11
* Mon Jan 25 2021 John Vandenberg <jayvdb@gmail.com>
- Fix Tumbleweed Python 3.6 build
* Sat Nov 28 2020 John Vandenberg <jayvdb@gmail.com>
- Activate test suite
* Mon Nov 23 2020 aloisio@gmx.com
- Update to version 1.0.0
  * Prevent invalid window bit sizes.
  * Added support for Python 3.8 and 3.9.
* Sun Oct 11 2020 John Vandenberg <jayvdb@gmail.com>
- Add missing runtime dependency on dataclasses
* Sat Aug 10 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.15.0
  * Drop support for Python 2. Please pin to ~= 0.14.0 if you
    support Python 2.
  * Drop support for Python 3.5, meaning the minimum supported
    version is Python 3.6.1.
  * Switch events to be dataclass based, otherwise the API is
    consistent.
  * Add type hints throughout and support PEP 561 via a py.typed
    file. This should allow projects that use wsproto to type
    check their usage of wsproto.
  * Bugfix prevent the test folder being installed as a package
    called test.
  * Explicitly require Host header in handshake.
  * Drop wsaccel support and utilise the aiohttp/@willmcgugan
    masking method. wsaccel is unmaintained and this new maksing
    method is almost as quick.
- Disable python2 build
* Fri May 31 2019 Luigi Baldoni <aloisio@gmx.com>
- Update to version 0.14.1
  * Loosen the h11 requirement to >= 0.8.1 as wsproto is
    compatible with 0.9 onwards.
  * Stop installing a "test" package on installation.
* Tue Apr  9 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.14.0
  * bugfix release, see CHANGELOG.rst
  0.13.0
  * many changes in connection management, see CHANGELOG.rst
* Tue Dec  4 2018 aloisio@gmx.com
- Update to version 0.12.0
  * Support h11 ~0.8.1.
  * Support Python 3.7.
  * Make the close-handshake more explicit, by sending a close
    frame on reciept of a close frame.
  * Bugfix fix deflate after a non-compressable message.
  * Bugfix connection header acceptance, by accepting Connection
    header values that are comma separated lists.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Sun Feb 25 2018 aloisio@gmx.com
- Initial package (0.11.0)
